# <brief> @<groups>

> <description>

> <links>

<data>

## Meta

> category  : <category>  
created   : <created>  
digest    : <digest>  
filename  : <filename>  
languages : <languages>  
name      : <name>  
source    : <source>  
tags      : <tags>  
updated   : <updated>  
uuid      : <uuid>  
versions  : <versions>  
